@@ -5,11 +5,13 @@
 """
 
 
-import degget
-import games_help
-import packages
-
+# import degget
+# import games_help
+# import packages
+from degget import show
+from games_help import gen_ru_words
+from packages import install, pip_upgrade, required
 
 __author__ = 'Superior_6564'
-__version__ = '0.0.2'
+__version__ = '0.0.3'
 __email__ = 'vip.klochayil@gmail.com'
